==> webkit2gtk_2.38.6.orig.tar.xz: webkitgtk-2.38.6/Source/WebKit/Shared/WebGPU/WebGPUShaderModuleDescriptor.cpp <==
/*
 * Copyright (C) 2021-2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUShaderModuleDescriptor.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <pal/graphics/WebGPU/WebGPUShaderModuleDescriptor.h>

namespace WebKit::WebGPU {

std::optional<ShaderModuleDescriptor> ConvertToBackingContext::convertToBacking(const PAL::WebGPU::ShaderModuleDescriptor& shaderModuleDescriptor)
{
    auto base = convertToBacking(static_cast<const PAL::WebGPU::ObjectDescriptorBase&>(shaderModuleDescriptor));
    if (!base)
        return std::nullopt;

    Vector<KeyValuePair<String, ShaderModuleCompilationHint>> hints;
    hints.reserveInitialCapacity(shaderModuleDescriptor.hints.size());
    for (const auto& hint : shaderModuleDescriptor.hints) {
        auto value = convertToBacking(hint.value);
        if (!value)
            return std::nullopt;
        hints.uncheckedAppend(makeKeyValuePair(hint.key, WTFMove(*value)));
    }

    return { { WTFMove(*base), shaderModuleDescriptor.code, WTFMove(hints) } };
}

std::optional<PAL::WebGPU::ShaderModuleDescriptor> ConvertFromBackingContext::convertFromBacking(const ShaderModuleDescriptor& shaderModuleDescriptor)
{
    auto base = convertFromBacking(static_cast<const ObjectDescriptorBase&>(shaderModuleDescriptor));
    if (!base)
        return std::nullopt;

    Vector<KeyValuePair<String, PAL::WebGPU::ShaderModuleCompilationHint>> hints;
    hints.reserveInitialCapacity(shaderModuleDescriptor.hints.size());
    for (const auto& hint : shaderModuleDescriptor.hints) {
        auto value = convertFromBacking(hint.value);
        if (!value)
            return std::nullopt;
        hints.uncheckedAppend(makeKeyValuePair(hint.key, WTFMove(*value)));
    }

    return { { WTFMove(*base), shaderModuleDescriptor.code, WTFMove(hints) } };
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)

==> webkit2gtk_2.42.2.orig.tar.xz: webkitgtk-2.42.2/Source/WebKit/Shared/WebGPU/WebGPUShaderModuleDescriptor.cpp <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUShaderModuleDescriptor.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <WebCore/WebGPUShaderModuleDescriptor.h>

namespace WebKit::WebGPU {

std::optional<ShaderModuleDescriptor> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::ShaderModuleDescriptor& shaderModuleDescriptor)
{
    auto base = convertToBacking(static_cast<const WebCore::WebGPU::ObjectDescriptorBase&>(shaderModuleDescriptor));
    if (!base)
        return std::nullopt;

    Vector<KeyValuePair<String, ShaderModuleCompilationHint>> hints;
    hints.reserveInitialCapacity(shaderModuleDescriptor.hints.size());
    for (const auto& hint : shaderModuleDescriptor.hints) {
        auto value = convertToBacking(hint.value);
        if (!value)
            return std::nullopt;
        hints.uncheckedAppend(makeKeyValuePair(hint.key, WTFMove(*value)));
    }

    return { { WTFMove(*base), shaderModuleDescriptor.code, WTFMove(hints) } };
}

std::optional<WebCore::WebGPU::ShaderModuleDescriptor> ConvertFromBackingContext::convertFromBacking(const ShaderModuleDescriptor& shaderModuleDescriptor)
{
    auto base = convertFromBacking(static_cast<const ObjectDescriptorBase&>(shaderModuleDescriptor));
    if (!base)
        return std::nullopt;

    Vector<KeyValuePair<String, WebCore::WebGPU::ShaderModuleCompilationHint>> hints;
    hints.reserveInitialCapacity(shaderModuleDescriptor.hints.size());
    for (const auto& hint : shaderModuleDescriptor.hints) {
        auto value = convertFromBacking(hint.value);
        if (!value)
            return std::nullopt;
        hints.uncheckedAppend(makeKeyValuePair(hint.key, WTFMove(*value)));
    }

    return { { WTFMove(*base), shaderModuleDescriptor.code, WTFMove(hints) } };
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)
